#!/bin/bash

#
#  Install script for Ethernet module STE101P on Olimex prototype board STM32-P107.
#  URL: http://olimex.com/dev/stm32-p107.html
#
#  Script written by Gregor Rebel 2010-2011.
# 
#  Feel free do distribute and change to your own needs!
#
# Tested successfully on:
# Ubuntu 10.04 Netbook Edition x86
# KUbuntu 11.04 x86
# openSuSE 11.4 x86
# XUbuntu 11.10 x64

source scripts/installFuncs.sh

if [ "$USER" == "root" ]; then
  echo "$0: ERROR this script should not been run as user root!"
  exit 10
fi

INSTALLPATH="Ethernet_STE101P"
dir $INSTALLPATH
cd $INSTALLPATH

#{ IMPLEMENT YOUR INSTALL SCRIPT BELOW -----------------------------------------------

if [ ! -e OK.Install ]; then #{
  echo "installing in $INSTALLPATH ..."
  InstallDir=`pwd`
  
  InstallInHomeDir="1"
  if [ "$InstallInHomeDir" == "1" ]; then
    Prefix=`pwd`  # install into subfolder of ToolChain/ for current user only
  else
    findPrefix    # install for all users
  fi
  
  get 'http://www.sics.se/~adam/download/?f=' uip-1.0-refman.pdf "TCP-IP_Stack_uIP_Manual.pdf" "../../Documentation/"
  File="STM32-P107_ethernet_demo_5.50"
  get http://olimex.com/dev/soft/arm/ST/STM-P107/ ${File}.zip
  unZIP  $File ${File}.zip
  #add2CleanUp ../cleanup.sh "rm -Rf $INSTALLPATH/$File"
  
  if [ ! -d ${File} ]; then
    echo "ERROR: Cannot download file (folder ${File} not found in `pwd`)!"
    exit 5
  fi
  #cd ${File}/
  if [ -d ${File} ]; then
    cd "${File}"
    File="Ethernet/app/uip-conf.h"
    if [ ! -e "${File}_orig" ]; then #{
        makeOrig ${File}
        echo "`pwd`> modifing ${File}.. (disabling double definitions)"
    
        replaceInFile ${File} 'typedef uint8_t u8_t;'     '#include "stm32_io.h" //ToolChain_STM32 already define in STM32_io.h  typedef uint8_t u8_t;'
        replaceInFile ${File} 'typedef uint16_t u16_t;'   '//ToolChain_STM32 already define in STM32_io.h  typedef uint16_t u16_t;'
        #replaceInFile ${File} ''                         '//ToolChain_STM32 already define in STM32_io.h  '
        
    fi #}
    
    File="Ethernet/app/ethernet.h"
    if [ ! -e "${File}_orig" ]; then #{
        makeOrig ${File}
        echo "`pwd`> modifing ${File}.. (disabling double definitions)"
    
        replaceInFile ${File} '#include "httpd.h"'     '//ToolChain_STM32 httpd not required for minimal TCP/IP - #include "httpd.h"'
        
    fi #}
    cd ..
  
    echo "" >$InstallDir/OK.Install
  fi
fi #} [ ! -e OK.Install ]; then
if [   -e OK.Install ]; then #{
  addLine ../scripts/createLinks.sh 'rm 2>/dev/null Ethernet_Demo;         ln -sv $Source/ToolChain_STM32/ToolChain/Ethernet_STE101P/STM32-P107_ethernet_demo_5.50/           Ethernet_Demo'
  echo "Installed successfully: $INSTALLPATH"
#}
else
  echo "failed to install $INSTALLPATH"
  exit 10
fi


cd ..

#} IMPLEMENT YOUR INSTALL SCRIPT ABOVE -----------------------------------------------

exit 0
